/* 
  SCLDisplay.h

  Barry McMullin <mcmullin@eeng.dcu.ie>
  01-OCT-1996


*/


#import <space/Object2dDisplay.h>


@interface SCLDisplay : Object2dDisplay

// Overridded methods...

-makeProbeAtX: (int) rasterX Y: (int) rasterY;

@end






